@@ -1,22 +1,22 @@
-use clap::{App, AppSettings, Arg};
+use clap::{Command, Arg};
 
-pub fn app() -> App<'static> {
-    App::new("config")
+pub fn app() -> Command<'static> {
+    Command::new("config")
         .about("Get Cronos program config info ")
         .subcommand(config_set_app())
 }
 
-fn config_set_app() -> App<'static> {
-    App::new("set")
+fn config_set_app() -> Command<'static> {
+    Command::new("set")
         .about("Set Cronos config variables")
-        .setting(AppSettings::SubcommandRequiredElseHelp)
+        .subcommand_required(true)
         .subcommand(config_set_min_recurr_app())
         .subcommand(config_set_program_fee_app())
         .subcommand(config_set_worker_fee_app())
 }
 
-fn config_set_min_recurr_app() -> App<'static> {
-    App::new("min_recurr")
+fn config_set_min_recurr_app() -> Command<'static> {
+    Command::new("min_recurr")
         .about("Update the minimum recurrence interval")
         .arg(
             Arg::new("new_value")
@@ -27,8 +27,8 @@ fn config_set_min_recurr_app() -> App<'static> {
         )
 }
 
-fn config_set_program_fee_app() -> App<'static> {
-    App::new("program_fee").about("Update the program fee").arg(
+fn config_set_program_fee_app() -> Command<'static> {
+    Command::new("program_fee").about("Update the program fee").arg(
         Arg::new("new_value")
             .index(1)
             .takes_value(true)
@@ -37,8 +37,8 @@ fn config_set_program_fee_app() -> App<'static> {
     )
 }
 
-fn config_set_worker_fee_app() -> App<'static> {
-    App::new("worker_fee").about("Update the worker fee").arg(
+fn config_set_worker_fee_app() -> Command<'static> {
+    Command::new("worker_fee").about("Update the worker fee").arg(
         Arg::new("new_value")
             .index(1)
             .takes_value(true)
